@@ -10,8 +10,6 @@ struct Args {
     file: String,
     #[clap(short, long)]
     output: Option<String>,
-    #[clap(arg_enum, short, long)]
-    generator: Option<generator::GeneratorType>,
 }
 
 fn main() -> io::Result<()> {
@@ -20,7 +18,6 @@ fn main() -> io::Result<()> {
     let in_file = args.file;
     let out_file: String;
 
-    // output file
     if let Some(of) = args.output {
         out_file = of;
     } else {
@@ -28,13 +25,7 @@ fn main() -> io::Result<()> {
     }
 
     let tokens = processor::DocTokenList::from_file(in_file);
-
-    // switches based off generator
-    let out_str = match args.generator {
-        Some(generator::GeneratorType::HTML) => generator::generate_html(tokens),
-        _ => generator::generate_ansi(tokens),
-    };
-
+    let out_str = generator::generate_ansi(tokens);
     fs::write(out_file, out_str)?;
 
     Ok(())
